@@ -62,6 +62,11 @@ Puppet::Type.newtype(:barbican_api_paste_ini) do
     defaultto('<SERVICE DEFAULT>')
   end
 
+  newparam(:key_val_separator) do
+    desc 'The separator string to use between each setting name and value.'
+    defaultto('=')
+  end
+
   autorequire(:anchor) do
     ['barbican::install::end']
   end
