@@ -12,12 +12,13 @@ describe 'barbican::keystone::auth' do
       end
 
       it { is_expected.to contain_keystone__resource__service_identity('barbican').with(
+        :configure_endpoint  => true,
         :configure_user      => true,
         :configure_user_role => true,
-        :configure_endpoint  => true,
+        :configure_service   => true,
         :service_name        => 'barbican',
         :service_type        => 'key-manager',
-        :service_description => 'Key management Service',
+        :service_description => 'OpenStack Key Manager Service',
         :region              => 'RegionOne',
         :auth_name           => 'barbican',
         :password            => 'barbican_password',
@@ -44,7 +45,8 @@ describe 'barbican::keystone::auth' do
           :configure_endpoint  => false,
           :configure_user      => false,
           :configure_user_role => false,
-          :service_description => 'Alternative Key management Service',
+          :configure_service   => false,
+          :service_description => 'Alternative OpenStack Key Manager Service',
           :service_name        => 'alt_service',
           :service_type        => 'alt_key-manager',
           :region              => 'RegionTwo',
@@ -57,9 +59,10 @@ describe 'barbican::keystone::auth' do
         :configure_user      => false,
         :configure_user_role => false,
         :configure_endpoint  => false,
+        :configure_service   => false,
         :service_name        => 'alt_service',
         :service_type        => 'alt_key-manager',
-        :service_description => 'Alternative Key management Service',
+        :service_description => 'Alternative OpenStack Key Manager Service',
         :region              => 'RegionTwo',
         :auth_name           => 'alt_barbican',
         :password            => 'barbican_password',
